from .randg import rand
from .hangman import hangman
from ..terminal import clear
from .uno import uno
from .wordle import wordle
from colorama import Fore as fore

def start():

  clear()
  
  def customisation():

    clear()

    style = int(input('''What colour would you like the game to be in?
    
[1] Red
[2] Blue
[3] Green
[4] Yellow
[5] White

'''))


    if style == 1:
      print(f'{fore.RED}')
    elif style == 2:
      print(f'{fore.BLUE}')
    elif style == 3:
      print(f'{fore.LIGHTGREEN_EX}')
    elif style == 4:
      print(f'{fore.LIGHTYELLOW_EX}')
    else:
      print(f'{fore.WHITE}')

  game = int(input('''What game would you like to play? 
  
[1] Uno
[2] Hangman
[3] Guess the Number
[4] Wordle
[5] Customization

'''))

  if game == 1:
    uno()
  if game == 2:
    hangman()
  if game == 3:
    rand()
  if game== 4:
   wordle()
  if game == 5:
    customisation()
    start()
  else:
    start()


# Hangman game
import random
import os

def hangman():
  
  WORDLIST_FILENAME = os.path.dirname(__file__)+"/./words.txt" # os path fix
  
  def loadWords():
      """
      Returns a list of valid words. Words are strings of lowercase letters.
      
      Depending on the size of the word list, this function may
      take a while to finish.
      """
      print("Loading word list from file...")
      # inFile: file
      inFile = open(WORDLIST_FILENAME, 'r')
      # line: string
      line = inFile.readline()
      # wordlist: list of strings
      wordlist = line.split()
      print("  ", len(wordlist), "words loaded.")
      return wordlist
  
  def chooseWord(wordlist):
      """
      wordlist (list): list of words (strings)
  
      Returns a word from wordlist at random
      """
      return random.choice(wordlist)
  
  # -----------------------------------
  wordlist = loadWords()
  
  def isWordGuessed(secretWord, lettersGuessed):
      '''
      secretWord: string, the word the user is guessing
      lettersGuessed: list, what letters have been guessed so far
      returns: boolean, True if all the letters of secretWord are in lettersGuessed;
        False otherwise
      '''
      c=0
      for i in lettersGuessed:
          if i in secretWord:
              c+=1
      if c==len(secretWord):
          return True
      else:
          return False
  
  
  def getGuessedWord(secretWord, lettersGuessed):
      '''
      secretWord: string, the word the user is guessing
      lettersGuessed: list, what letters have been guessed so far
      returns: string, comprised of letters and underscores that represents
        what letters in secretWord have been guessed so far.
      '''
      s=[]
      for i in secretWord:
          if i in lettersGuessed:
              s.append(i)
      ans=''
      for i in secretWord:
          if i in s:
              ans+=i
          else:
              ans+='_ '
      return ans
  
  
  
  def getAvailableLetters(lettersGuessed):
      '''
      lettersGuessed: list, what letters have been guessed so far
      returns: string, comprised of letters that represents what letters have not
        yet been guessed.
      '''
      import string
      ans=list(string.ascii_lowercase)
      for i in lettersGuessed:
          ans.remove(i)
      return ''.join(ans)
  
  def hangman(secretWord):
      '''
      secretWord: string, the secret word to guess.
  
      Starts up an interactive game of Hangman.
  
      * At the start of the game, let the user know how many 
        letters the secretWord contains.
  
      * Ask the user to supply one guess (i.e. letter) per round.
  
      * The user should receive feedback immediately after each guess 
        about whether their guess appears in the computers word.
  
      * After each round, you should also display to the user the 
        partially guessed word so far, as well as letters that the 
        user has not yet guessed.
  
      Follows the other limitations detailed in the problem write-up.
      '''
      print("Welcome to the game, Hangman!")
      print("I am thinking of a word that is",len(secretWord),"letters long.")
      
      global lettersGuessed
      mistakeMade=0
      lettersGuessed=[]
      
      while 8 - mistakeMade > 0:
          
          if isWordGuessed(secretWord, lettersGuessed):
              print("-------------")
              print("Congratulations, you won!")
              break
              
          else:
              print("-------------")
              print("You have",8-mistakeMade,"guesses left.")
              print("Available letters:",getAvailableLetters(lettersGuessed))
              guess=str(input("Please guess a letter: ")).lower()
              
              if guess in lettersGuessed:
                  print("Oops! You've already guessed that letter:",getGuessedWord(secretWord,lettersGuessed))
                  
              elif guess in secretWord and guess not in lettersGuessed:
                  lettersGuessed.append(guess)
                  print("Good guess:",getGuessedWord(secretWord,lettersGuessed))
                  
              else:
                  lettersGuessed.append(guess)
                  mistakeMade += 1
                  print("Oops! That letter is not in my word:",getGuessedWord(secretWord,lettersGuessed))
                  
          if 8 - mistakeMade == 0:
              print("-------------")
              print("Sorry, you ran out of guesses. The word was else.",secretWord)
              break
          
          else:
              continue
  
  
  secretWord = chooseWord(wordlist).lower()
  hangman(secretWord)


import random
import sys

low = 1
high = 30
guesslimit = 5

def rand():
  
  print("Guess a number between {0} and {1}".format(low, high))
  print("You have {0} guesses to get the right number".format(guesslimit))
  
  guessnumb = 0
  number = random.randint(low, high)
  
  try:
  	while guessnumb < guesslimit:
  		try:
  			guess = int(input('What\'s your guess? '))
  		except ValueError:
  			print("Couldn\'t convert input to Integer")
  			continue
  	
  		if guess < low or guess > high:
  			print("Value out of range ({0} - {1})".format(low, high))
  		else:
  			guessnumb += 1
  			
  			if guess < number:
  				print("Your guess was too low")
  		
  			if guess > number:
  				print("Your guess was too high")
  		
  			if guess == number:
  				break
  	
  except KeyboardInterrupt:
  	print("\n  ^C detected, terminating...")
  	sys.exit()
  
  except EOFError:
  	print("\n  ^D detected, terminating...")
  	sys.exit()
  
  if guess == number:
  	print("Great, you guessed the number in {0} trys".format(guessnumb))
  else:
  	print("No, I was thinking of the number {0}".format(number))